@@ -46,27 +46,12 @@ bg_flickr_source_dispose (GObject *object)
 {
   BgFlickrSourcePrivate *priv = BG_FLICKR_SOURCE (object)->priv;
 
-  if (priv->client)
-    {
-      g_object_unref (priv->client);
-      priv->client = NULL;
-    }
-
-  if (priv->service)
-    {
-      g_object_unref (priv->service);
-      priv->service = NULL;
-    }
+  g_clear_object (&priv->client);
+  g_clear_object (&priv->service);
 
   G_OBJECT_CLASS (bg_flickr_source_parent_class)->dispose (object);
 }
 
-static void
-bg_flickr_source_finalize (GObject *object)
-{
-  G_OBJECT_CLASS (bg_flickr_source_parent_class)->finalize (object);
-}
-
 static void
 bg_flickr_source_class_init (BgFlickrSourceClass *klass)
 {
@@ -75,7 +60,6 @@ bg_flickr_source_class_init (BgFlickrSourceClass *klass)
   g_type_class_add_private (klass, sizeof (BgFlickrSourcePrivate));
 
   object_class->dispose = bg_flickr_source_dispose;
-  object_class->finalize = bg_flickr_source_finalize;
 }
 
 static void
@@ -118,7 +102,6 @@ _view_items_added_cb (SwClientItemView *item_view,
                                          1, item,
                                          -1);
       g_object_unref (pixbuf);
-      g_object_unref (item);
     }
 }
 
