@@ -72,26 +72,12 @@ bg_wallpapers_source_dispose (GObject *object)
 {
   BgWallpapersSourcePrivate *priv = BG_WALLPAPERS_SOURCE (object)->priv;
 
-  if (priv->thumb_factory)
-    {
-      g_object_unref (priv->thumb_factory);
-      priv->thumb_factory = NULL;
-    }
-  if (priv->xml)
-    {
-      g_object_unref (priv->xml);
-      priv->xml = NULL;
-    }
+  g_clear_object (&priv->thumb_factory);
+  g_clear_object (&priv->xml);
 
   G_OBJECT_CLASS (bg_wallpapers_source_parent_class)->dispose (object);
 }
 
-static void
-bg_wallpapers_source_finalize (GObject *object)
-{
-  G_OBJECT_CLASS (bg_wallpapers_source_parent_class)->finalize (object);
-}
-
 static void
 bg_wallpapers_source_class_init (BgWallpapersSourceClass *klass)
 {
@@ -102,7 +88,6 @@ bg_wallpapers_source_class_init (BgWallpapersSourceClass *klass)
   object_class->get_property = bg_wallpapers_source_get_property;
   object_class->set_property = bg_wallpapers_source_set_property;
   object_class->dispose = bg_wallpapers_source_dispose;
-  object_class->finalize = bg_wallpapers_source_finalize;
 }
 
 static void
@@ -128,7 +113,7 @@ load_wallpapers (gchar              *key,
 
   gtk_list_store_set (store, &iter,
                       0, pixbuf,
-                      1, item,
+                      1, g_object_ref (item),
                       2, cc_background_item_get_name (item),
                       -1);
 
