@@ -140,8 +140,7 @@ cc_background_item_changes_with_time (CcBackgroundItem *item)
 static void
 update_size (CcBackgroundItem *item)
 {
-	g_free (item->priv->size);
-	item->priv->size = NULL;
+	g_clear_pointer (&item->priv->size, g_free);
 
 	if (item->priv->uri == NULL) {
 		item->priv->size = g_strdup ("");
@@ -272,8 +271,7 @@ update_info (CcBackgroundItem *item,
 		info = g_object_ref (_info);
 	}
 
-        g_free (item->priv->mime_type);
-        item->priv->mime_type = NULL;
+	g_clear_pointer (&item->priv->mime_type, g_free);
 
         if (info == NULL
             || g_file_info_get_content_type (info) == NULL) {
@@ -798,8 +796,6 @@ cc_background_item_finalize (GObject *object)
         g_free (item->priv->secondary_color);
         g_free (item->priv->mime_type);
         g_free (item->priv->size);
-        g_free (item->priv->source_url);
-        g_free (item->priv->source_xml);
 
         if (item->priv->bg != NULL)
                 g_object_unref (item->priv->bg);
@@ -896,9 +892,9 @@ cc_background_item_dump (CcBackgroundItem *item)
 	g_debug ("flags:\t\t\t%s", flags->str);
 	g_string_free (flags, TRUE);
 	if (priv->primary_color)
-		g_debug ("pcolor:\t\t\t%s", priv->primary_color);
+		g_debug ("pcolor:\t\t%s", priv->primary_color);
 	if (priv->secondary_color)
-		g_debug ("scolor:\t\t\t%s", priv->secondary_color);
+		g_debug ("scolor:\t\t%s", priv->secondary_color);
 	g_debug ("placement:\t\t%s", enum_to_str (G_DESKTOP_TYPE_DESKTOP_BACKGROUND_STYLE, priv->placement));
 	g_debug ("shading:\t\t%s", enum_to_str (G_DESKTOP_TYPE_DESKTOP_BACKGROUND_SHADING, priv->shading));
 	if (priv->source_url)
