@@ -101,8 +101,7 @@ cc_background_panel_dispose (GObject *object)
       /* cancel any copy operation */
       g_cancellable_cancel (priv->copy_cancellable);
 
-      g_object_unref (priv->copy_cancellable);
-      priv->copy_cancellable = NULL;
+      g_clear_object (&priv->copy_cancellable);
     }
 
   if (priv->capture_cancellable)
@@ -110,8 +109,7 @@ cc_background_panel_dispose (GObject *object)
       /* cancel screenshot operations */
       g_cancellable_cancel (priv->capture_cancellable);
 
-      g_object_unref (priv->capture_cancellable);
-      priv->capture_cancellable = NULL;
+      g_clear_object (&priv->capture_cancellable);
     }
 
   if (priv->chooser)
@@ -123,10 +121,7 @@ cc_background_panel_dispose (GObject *object)
   g_clear_object (&priv->thumb_factory);
   g_clear_object (&priv->display_screenshot);
 
-  g_free (priv->screenshot_path);
-  priv->screenshot_path = NULL;
-
-  g_clear_object (&priv->connection);
+  g_clear_pointer (&priv->screenshot_path, g_free);
 
   G_OBJECT_CLASS (cc_background_panel_parent_class)->dispose (object);
 }
@@ -318,7 +313,9 @@ on_screenshot_finished (GObject *source,
   surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
                                         data->monitor_rect.width, data->monitor_rect.height);
   cr = cairo_create (surface);
-  gdk_cairo_set_source_pixbuf (cr, pixbuf, data->capture_rect.x, data->capture_rect.y);
+  gdk_cairo_set_source_pixbuf (cr, pixbuf,
+                               data->capture_rect.x - data->monitor_rect.x,
+                               data->capture_rect.y - data->monitor_rect.y);
   cairo_paint (cr);
   g_object_unref (pixbuf);
 
@@ -344,8 +341,7 @@ on_screenshot_finished (GObject *source,
 
   /* remove the temporary file created by the shell */
   g_unlink (panel->priv->screenshot_path);
-  g_free (priv->screenshot_path);
-  priv->screenshot_path = NULL;
+  g_clear_pointer (&priv->screenshot_path, g_free);
 
   cairo_destroy (cr);
   cairo_surface_destroy (surface);
@@ -393,7 +389,7 @@ get_screenshot_async (CcBackgroundPanel *panel)
   if (calculate_contiguous_workarea (data)) {
     g_debug ("Capturing only a portion of the screen");
   } else {
-    g_debug ("Capturing the whole screen");
+    g_debug ("Capturing the whole monitor");
     data->whole_monitor = TRUE;
     data->capture_rect = data->monitor_rect;
   }
@@ -478,8 +474,7 @@ reload_current_bg (CcBackgroundPanel *self,
   uri = g_settings_get_string (settings, WP_URI_KEY);
   if (uri && *uri == '\0')
     {
-      g_free (uri);
-      uri = NULL;
+      g_clear_pointer (&uri, g_free);
     }
   else
     {
@@ -596,6 +591,7 @@ copy_finished_cb (GObject      *source_object,
       char *filename;
 
       update_preview (priv, settings, item);
+      current_background = CURRENT_BG;
 
       /* Save the source XML if there is one */
       filename = get_save_path (SAVE_PATH);
