@@ -39,7 +39,6 @@ struct CcBackgroundXmlPrivate
   GHashTable  *wp_hash;
   GAsyncQueue *item_added_queue;
   guint        item_added_id;
-  GSList      *monitors; /* GSList of GFileMonitor */
 };
 
 #define CC_BACKGROUND_XML_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CC_TYPE_BACKGROUND_XML, CcBackgroundXmlPrivate))
@@ -292,7 +291,6 @@ cc_background_xml_load_xml_internal (CcBackgroundXml *xml,
 	        g_object_unref (item);
 	        continue;
 	      }
-	    g_object_unref (file);
 	  }
       }
 
@@ -300,7 +298,6 @@ cc_background_xml_load_xml_internal (CcBackgroundXml *xml,
        * need to use proper code here */
       uri = g_filename_to_uri (filename, NULL, NULL);
       id = g_strdup_printf ("%s#%s", uri, cname);
-      g_free (cname);
       g_free (uri);
 
       /* Make sure we don't already have this one and that filename exists */
@@ -311,16 +308,12 @@ cc_background_xml_load_xml_internal (CcBackgroundXml *xml,
       }
 
       g_object_set (G_OBJECT (item), "flags", flags, NULL);
-      g_hash_table_insert (xml->priv->wp_hash,
-                           g_strdup (id),
-                           g_object_ref (item));
+      g_hash_table_insert (xml->priv->wp_hash, id, item);
+      /* Don't free ID, we added it to the hash table */
       if (in_thread)
         emit_added_in_idle (xml, g_object_ref (item));
       else
         g_signal_emit (G_OBJECT (xml), signals[ADDED], 0, item);
-
-      g_object_unref (item);
-      g_free (id);
       retval = TRUE;
     }
   }
@@ -375,8 +368,6 @@ cc_background_xml_add_monitor (GFile      *directory,
   g_signal_connect (monitor, "changed",
                     G_CALLBACK (gnome_wp_file_changed),
                     data);
-
-  data->priv->monitors = g_slist_prepend (data->priv->monitors, monitor);
 }
 
 static void
@@ -632,21 +623,12 @@ cc_background_xml_finalize (GObject *object)
 
         g_return_if_fail (xml->priv != NULL);
 
-	if (xml->priv->wp_hash) {
-		g_hash_table_destroy (xml->priv->wp_hash);
-		xml->priv->wp_hash = NULL;
-	}
-
-        g_slist_free_full (xml->priv->monitors, g_object_unref);
-
+	g_clear_pointer (&xml->priv->wp_hash, g_hash_table_destroy);
 	if (xml->priv->item_added_id != 0) {
 		g_source_remove (xml->priv->item_added_id);
 		xml->priv->item_added_id = 0;
 	}
-	if (xml->priv->item_added_queue) {
-		g_async_queue_unref (xml->priv->item_added_queue);
-		xml->priv->item_added_queue = NULL;
-	}
+	g_clear_pointer (&xml->priv->item_added_queue, g_async_queue_unref);
 }
 
 static void
