@@ -42,7 +42,6 @@ typedef struct {
         GtkWidget *filter_entry;
         GtkWidget *language_list;
         GtkWidget *scrolledwindow;
-        gboolean adding_languages;
         gboolean showing_extra;
         gchar *language;
         gchar **filter_words;
@@ -150,8 +149,6 @@ add_languages (GtkDialog   *chooser,
 {
         CcLanguageChooserPrivate *priv = GET_PRIVATE (chooser);
 
-        priv->adding_languages = TRUE;
-
         while (*locale_ids) {
                 gchar *locale_id;
                 gboolean is_initial;
@@ -171,8 +168,6 @@ add_languages (GtkDialog   *chooser,
         gtk_container_add (GTK_CONTAINER (priv->language_list), GTK_WIDGET (priv->more_item));
 
         gtk_widget_show_all (priv->language_list);
-
-        priv->adding_languages = FALSE;
 }
 
 static void
@@ -357,9 +352,6 @@ row_activated (GtkListBox        *box,
         CcLanguageChooserPrivate *priv = GET_PRIVATE (chooser);
         gchar *new_locale_id;
 
-        if (priv->adding_languages)
-                return;
-
         if (row == NULL)
                 return;
 
@@ -376,18 +368,17 @@ update_header_func (GtkListBoxRow  *row,
                     GtkListBoxRow  *before,
                     gpointer    user_data)
 {
-  GtkWidget *current;
+        GtkWidget *current;
 
-  if (before == NULL)
-    return;
+        if (before == NULL)
+                return;
 
-  current = gtk_list_box_row_get_header (row);
-  if (current == NULL)
-    {
-      current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-      gtk_widget_show (current);
-      gtk_list_box_row_set_header (row, current);
-    }
+        current = gtk_list_box_row_get_header (row);
+        if (current == NULL) {
+                current = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
+                gtk_widget_show (current);
+                gtk_list_box_row_set_header (row, current);
+        }
 }
 
 static void
@@ -444,7 +435,7 @@ cc_language_chooser_new (GtkWidget *parent)
                                       update_header_func, NULL, NULL);
         add_all_languages (GTK_DIALOG (chooser));
 
-        g_signal_connect_swapped (priv->filter_entry, "changed",
+        g_signal_connect_swapped (priv->filter_entry, "search-changed",
                                   G_CALLBACK (filter_changed), chooser);
 
         g_signal_connect (priv->language_list, "row-activated",
