@@ -79,6 +79,8 @@ struct _CcDisplayPanelPrivate
   GtkWidget *res_combo;
   GtkWidget *rotate_left_button;
   GtkWidget *rotate_right_button;
+  GtkWidget *apply_button;
+  GtkWidget *dialog;
 
   UpClient *up_client;
   gboolean lid_is_closed;
@@ -139,6 +141,12 @@ cc_display_panel_dispose (GObject *object)
   g_clear_object (&priv->background);
   g_clear_object (&priv->thumbnail_factory);
 
+  if (priv->dialog)
+    {
+      gtk_widget_destroy (priv->dialog);
+      priv->dialog = NULL;
+    }
+
   G_OBJECT_CLASS (cc_display_panel_parent_class)->dispose (object);
 }
 
@@ -1063,6 +1071,78 @@ grab_weak_ref_notify (gpointer  area,
   foo_scroll_area_end_grab (area, NULL);
 }
 
+static GnomeRROutputInfo *
+find_output (GnomeRROutputInfo **outputs,
+             const gchar        *name)
+{
+  int i;
+
+  for (i = 0; outputs[i]; i++)
+    {
+      if (g_str_equal (gnome_rr_output_info_get_name (outputs[i]), name))
+        return outputs[i];
+    }
+  return NULL;
+}
+
+static void
+update_apply_button (CcDisplayPanel *panel)
+{
+  CcDisplayPanelPrivate *priv = panel->priv;
+  gboolean config_equal;
+  GnomeRRConfig *current_configuration;
+
+  current_configuration = gnome_rr_config_new_current (priv->screen, NULL);
+
+  /* this checks if the same modes will be set on the outputs */
+  config_equal = gnome_rr_config_equal (priv->current_configuration,
+                                        current_configuration);
+
+  if (config_equal)
+    {
+      /* check if clone state has changed */
+      if (gnome_rr_config_get_clone (priv->current_configuration)
+          != gnome_rr_config_get_clone (current_configuration))
+        {
+          config_equal = FALSE;
+        }
+      else
+        {
+          GnomeRROutputInfo **new_outputs, **current_outputs;
+          int i;
+
+          /* check if primary display has changed */
+          new_outputs = gnome_rr_config_get_outputs (priv->current_configuration);
+          current_outputs = gnome_rr_config_get_outputs (current_configuration);
+
+          for (i = 0; new_outputs[i]; i++)
+            {
+              GnomeRROutputInfo *output;
+
+              output = find_output (current_outputs,
+                                    gnome_rr_output_info_get_name (new_outputs[i]));
+
+              if (!output)
+                {
+                  config_equal = FALSE;
+                  break;
+                }
+
+              if (gnome_rr_output_info_get_primary (new_outputs[i])
+                  != gnome_rr_output_info_get_primary (output))
+                {
+                  config_equal = FALSE;
+                  break;
+                }
+            }
+        }
+    }
+
+  g_object_unref (current_configuration);
+
+  gtk_widget_set_sensitive (priv->apply_button, !config_equal);
+}
+
 static void
 on_output_event (FooScrollArea *area,
                  FooScrollAreaEvent *event,
@@ -1174,6 +1254,7 @@ on_output_event (FooScrollArea *area,
 	      g_free (g_object_get_data (G_OBJECT (output), "grab-info"));
 	      g_object_set_data (G_OBJECT (output), "grab-info", NULL);
 	      g_object_weak_unref (data, grab_weak_ref_notify, area);
+              update_apply_button (self);
 
 #if 0
               g_debug ("new position: %d %d %d %d", output->x, output->y, output->width, output->height);
@@ -1373,20 +1454,44 @@ apply_current_configuration (CcDisplayPanel *self)
     }
 }
 
+static void
+dialog_toplevel_focus_changed (GtkWindow      *window,
+                               GParamSpec     *pspec,
+                               CcDisplayPanel *self)
+{
+  CcDisplayPanelPrivate *priv = self->priv;
+
+  if (priv->labeler == NULL)
+    return;
+
+  if (gtk_window_has_toplevel_focus (window))
+    cc_rr_labeler_show (priv->labeler);
+  else
+    cc_rr_labeler_hide (priv->labeler);
+}
+
 static void
 show_arrange_displays_dialog (GtkButton      *button,
                               CcDisplayPanel *panel)
 {
-  GtkWidget *dialog, *content_area, *area, *vbox, *label;
+  CcDisplayPanelPrivate *priv = panel->priv;
+  GtkWidget *content_area, *area, *vbox, *label;
+  gint response;
 
-  dialog = gtk_dialog_new_with_buttons (_("Arrange Combined Displays"),
-                                        GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))),
-                                        GTK_DIALOG_MODAL,
-                                        _("_Cancel"), GTK_RESPONSE_REJECT,
-                                        _("_Apply"), GTK_RESPONSE_ACCEPT,
-                                        NULL);
+  priv->dialog = gtk_dialog_new ();
+  g_signal_connect (priv->dialog, "notify::has-toplevel-focus",
+                    G_CALLBACK (dialog_toplevel_focus_changed), panel);
+  gtk_window_set_title (GTK_WINDOW (priv->dialog), _("Arrange Combined Displays"));
+  gtk_window_set_transient_for (GTK_WINDOW (priv->dialog),
+                                GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))));
+  gtk_window_set_modal (GTK_WINDOW (priv->dialog), TRUE);
+  gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Cancel"),
+                         GTK_RESPONSE_REJECT);
+  priv->apply_button = gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Apply"),
+                                              GTK_RESPONSE_ACCEPT);
+  gtk_widget_set_sensitive (priv->apply_button, FALSE);
 
-  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (priv->dialog));
 
   area = (GtkWidget *) foo_scroll_area_new ();
   g_object_set_data (G_OBJECT (area), "panel", panel);
@@ -1412,15 +1517,23 @@ show_arrange_displays_dialog (GtkButton      *button,
   gtk_widget_show_all (vbox);
   gtk_container_add (GTK_CONTAINER (content_area), vbox);
 
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+  response = gtk_dialog_run (GTK_DIALOG (priv->dialog));
+  if (response == GTK_RESPONSE_ACCEPT)
     apply_current_configuration (panel);
+  else if (response == GTK_RESPONSE_NONE)
+    {
+      /* panel is being destroyed */
+      return;
+    }
   else
     {
       /* re-read the previous configuration */
       on_screen_changed (panel);
     }
 
-  gtk_widget_destroy (dialog);
+  priv->apply_button = NULL;
+  gtk_widget_destroy (priv->dialog);
+  priv->dialog = NULL;
 }
 
 static const gchar *
@@ -1633,22 +1746,9 @@ setup_listbox_row_activated (GtkListBox     *list_box,
 
   setup_resolution_combo_box (panel, modes,
                               gnome_rr_output_get_current_mode (output));
+  update_apply_button (panel);
 }
 
-static void
-dialog_toplevel_focus_changed (GtkWindow      *window,
-			       GParamSpec     *pspec,
-			       CcDisplayPanel *self)
-{
-  if (self->priv->labeler == NULL)
-    return;
-  if (gtk_window_has_toplevel_focus (window))
-    cc_rr_labeler_show (self->priv->labeler);
-  else
-    cc_rr_labeler_hide (self->priv->labeler);
-}
-
-
 static void
 rotate_left_clicked (GtkButton      *button,
                      CcDisplayPanel *panel)
@@ -1670,6 +1770,7 @@ rotate_left_clicked (GtkButton      *button,
     }
 
   gnome_rr_output_info_set_rotation (priv->current_output, rotation);
+  update_apply_button (panel);
 }
 
 static void
@@ -1693,6 +1794,7 @@ rotate_right_clicked (GtkButton      *button,
     }
 
   gnome_rr_output_info_set_rotation (priv->current_output, rotation);
+  update_apply_button (panel);
 }
 
 static const double known_diagonals[] = {
@@ -1756,6 +1858,7 @@ res_combo_changed (GtkComboBox    *combo,
       height = gnome_rr_mode_get_height (mode);
 
       gnome_rr_output_info_set_geometry (priv->current_output, x, y, width, height);
+      update_apply_button (panel);
     }
 }
 
@@ -1763,7 +1866,7 @@ static void
 show_setup_dialog (CcDisplayPanel *panel)
 {
   CcDisplayPanelPrivate *priv = panel->priv;
-  GtkWidget *dialog, *listbox, *content_area, *item, *box, *frame, *preview;
+  GtkWidget *listbox = NULL, *content_area, *item, *box, *frame, *preview;
   GtkWidget *label, *rotate_box, *grid;
   gint i, width_mm, height_mm, old_width, old_height;
   GnomeRROutput *output;
@@ -1772,20 +1875,28 @@ show_setup_dialog (CcDisplayPanel *panel)
   GtkListStore *res_model;
   GtkCellRenderer *renderer;
   GnomeRRRotation rotation;
+  gint response;
 
   output = gnome_rr_screen_get_output_by_name (priv->screen,
                                                gnome_rr_output_info_get_name (priv->current_output));
 
 
-  dialog = gtk_dialog_new_with_buttons (gnome_rr_output_info_get_display_name (priv->current_output),
-                                        GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))),
-                                        GTK_DIALOG_MODAL,
-                                        _("_Cancel"), GTK_RESPONSE_REJECT,
-                                        _("_Apply"), GTK_RESPONSE_ACCEPT,
-                                        NULL);
-  gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+  priv->dialog = gtk_dialog_new ();
+  g_signal_connect (priv->dialog, "notify::has-toplevel-focus",
+                    G_CALLBACK (dialog_toplevel_focus_changed), panel);
+  gtk_window_set_title (GTK_WINDOW (priv->dialog),
+                        gnome_rr_output_info_get_display_name (priv->current_output));
+  gtk_window_set_transient_for (GTK_WINDOW (priv->dialog),
+                                GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))));
+  gtk_window_set_modal (GTK_WINDOW (priv->dialog), TRUE);
+  gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Cancel"),
+                         GTK_RESPONSE_REJECT);
+  priv->apply_button = gtk_dialog_add_button (GTK_DIALOG (priv->dialog),
+                                              _("_Apply"), GTK_RESPONSE_ACCEPT);
+  gtk_widget_set_sensitive (priv->apply_button, FALSE);
+  gtk_window_set_resizable (GTK_WINDOW (priv->dialog), FALSE);
 
-  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (priv->dialog));
 
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_widget_set_margin_left (box, 12);
@@ -1948,14 +2059,15 @@ show_setup_dialog (CcDisplayPanel *panel)
                                   gnome_rr_output_get_current_mode (output));
     }
 
-  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (priv->dialog));
   gtk_container_add (GTK_CONTAINER (box), grid);
   gtk_widget_show_all (box);
 
   gnome_rr_output_info_get_geometry (priv->current_output, NULL, NULL,
                                      &old_width, &old_height);
 
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+  response = gtk_dialog_run (GTK_DIALOG (priv->dialog));
+  if (response == GTK_RESPONSE_ACCEPT)
     {
       GnomeRROutputInfo **outputs;
       GtkListBoxRow *row;
@@ -2048,6 +2160,11 @@ show_setup_dialog (CcDisplayPanel *panel)
 
       apply_current_configuration (panel);
     }
+  else if (response == GTK_RESPONSE_NONE)
+    {
+      /* panel is being destroyed */
+      return;
+    }
   else
     {
       /* changes cancelled, so re-read the current configuration */
@@ -2057,7 +2174,9 @@ show_setup_dialog (CcDisplayPanel *panel)
   priv->rotate_left_button = NULL;
   priv->rotate_right_button = NULL;
   priv->res_combo = NULL;
-  gtk_widget_destroy (dialog);
+  priv->apply_button = NULL;
+  gtk_widget_destroy (priv->dialog);
+  priv->dialog = NULL;
 }
 
 static void
