@@ -1062,6 +1062,7 @@ on_control_stream_added (GvcMixerControl *control,
             (GVC_IS_MIXER_SOURCE (stream) == FALSE &&
              GVC_IS_MIXER_SINK (stream) == FALSE &&
              gvc_mixer_stream_is_virtual (stream) == FALSE &&
+             gvc_mixer_stream_is_event_stream (stream) == FALSE &&
              g_strcmp0 (app_id, "org.gnome.VolumeControl") != 0 &&
              g_strcmp0 (app_id, "org.PulseAudio.pavucontrol") != 0)) {
                 GtkWidget      *bar;
@@ -1592,7 +1593,7 @@ on_test_speakers_clicked (GvcComboBox *widget,
         d = gtk_dialog_new_with_buttons (title,
                                          GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (widget))),
                                          GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                         _("_Close"), GTK_RESPONSE_CLOSE,
                                          NULL);
         gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
 
