@@ -36,7 +36,7 @@
 #include "run-passwd.h"
 #include "pw-utils.h"
 
-#define PASSWORD_CHECK_TIMEOUT 500
+#define PASSWORD_CHECK_TIMEOUT 600
 
 struct _UmPasswordDialog {
         GtkWidget *dialog;
@@ -47,17 +47,15 @@ struct _UmPasswordDialog {
         GtkWidget *verify_entry;
         gint       password_entry_timeout_id;
         GtkWidget *strength_indicator;
-        GtkWidget *strength_indicator_label;
         GtkWidget *ok_button;
         GtkWidget *password_hint;
+        GtkWidget *verify_hint;
 
         ActUser *user;
         ActUserPasswordMode password_mode;
 
         GtkWidget *old_password_label;
         GtkWidget *old_password_entry;
-        GtkWidget *old_password_checkmark;
-        GtkWidget *old_password_spinner;
         gboolean   old_password_ok;
         gint       old_password_entry_timeout_id;
 
@@ -73,8 +71,6 @@ update_password_strength (UmPasswordDialog *um)
         gint strength_level;
         const gchar *hint;
         const gchar *long_hint;
-        const gchar *verify;
-        const gchar *strength_hint;
 
         if (um->user == NULL) {
                 return 0;
@@ -87,19 +83,15 @@ update_password_strength (UmPasswordDialog *um)
         pw_strength (password, old_password, username,
                      &hint, &long_hint, &strength_level);
 
-        if (strlen (password) == 0) {
-                strength_hint = "";
-        } else {
-                strength_hint = hint;
-        }
-
         gtk_level_bar_set_value (GTK_LEVEL_BAR (um->strength_indicator), strength_level);
-        gtk_label_set_label (GTK_LABEL (um->strength_indicator_label), strength_hint);
         gtk_label_set_label (GTK_LABEL (um->password_hint), long_hint);
 
-        verify = gtk_entry_get_text (GTK_ENTRY (um->verify_entry));
-        if (strlen (verify) == 0) {
-                gtk_widget_set_sensitive (um->verify_entry, strength_level > 0);
+        if (strength_level > 0) {
+                set_entry_validation_checkmark (GTK_ENTRY (um->password_entry));
+        } else if (strlen (password) == 0) {
+                set_entry_generation_icon (GTK_ENTRY (um->password_entry));
+        } else {
+                clear_entry_validation_error (GTK_ENTRY (um->password_entry));
         }
 
         return strength_level;
@@ -260,7 +252,6 @@ mode_change (UmPasswordDialog *um,
         gtk_widget_set_sensitive (um->password_entry, active);
         gtk_widget_set_sensitive (um->verify_entry, active);
         gtk_widget_set_sensitive (um->old_password_entry, active);
-        gtk_widget_set_sensitive (um->strength_indicator_label, active);
         gtk_widget_set_sensitive (um->password_hint, active);
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (um->action_now_radio), active);
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (um->action_login_radio), !active);
@@ -292,13 +283,12 @@ update_password_match (UmPasswordDialog *um)
 
         if (strlen (password) > 0 && strlen (verify) > 0) {
                 if (strcmp (password, verify) != 0) {
-                        gtk_label_set_label (GTK_LABEL (um->password_hint),
+                        gtk_label_set_label (GTK_LABEL (um->verify_hint),
                                              _("The passwords do not match."));
-                        set_entry_validation_error (GTK_ENTRY (um->verify_entry),
-                                                    _("Passwords do not match"));
                 }
                 else {
-                        clear_entry_validation_error (GTK_ENTRY (um->verify_entry));
+                        gtk_label_set_label (GTK_LABEL (um->verify_hint), "");
+                        set_entry_validation_checkmark (GTK_ENTRY (um->verify_entry));
                 }
         }
 }
@@ -320,12 +310,21 @@ password_entry_changed (GtkEntry         *entry,
                       GParamSpec       *pspec,
                       UmPasswordDialog *um)
 {
+        const char *password;
+
         if (um->password_entry_timeout_id != 0) {
                 g_source_remove (um->password_entry_timeout_id);
                 um->password_entry_timeout_id = 0;
         }
 
         clear_entry_validation_error (GTK_ENTRY (entry));
+        clear_entry_validation_error (GTK_ENTRY (um->verify_entry));
+        gtk_widget_set_sensitive (um->ok_button, FALSE);
+
+        password = gtk_entry_get_text (GTK_ENTRY (um->password_entry));
+        if (strlen (password) == 0) {
+                gtk_entry_set_visibility (GTK_ENTRY (um->password_entry), FALSE);
+        }
 
         um->password_entry_timeout_id = g_timeout_add (PASSWORD_CHECK_TIMEOUT,
                                                      (GSourceFunc) password_entry_timeout,
@@ -347,36 +346,17 @@ password_entry_focus_out (GtkWidget        *entry,
         return FALSE;
 }
 
-static void
-begin_action (UmPasswordDialog *um)
-{
-        gtk_widget_show (um->old_password_spinner);
-        gtk_spinner_start (GTK_SPINNER (um->old_password_spinner));
-}
-
-static void
-finish_action (UmPasswordDialog *um)
-{
-        gtk_widget_hide (um->old_password_spinner);
-        gtk_spinner_stop (GTK_SPINNER (um->old_password_spinner));
-}
-
 static void
 auth_cb (PasswdHandler    *handler,
          GError           *error,
          UmPasswordDialog *um)
 {
-        finish_action (um);
-
         if (error) {
                 um->old_password_ok = FALSE;
-                set_entry_validation_error (GTK_ENTRY (um->old_password_entry),
-                                            _("Wrong password"));
         }
         else {
                 um->old_password_ok = TRUE;
-                clear_entry_validation_error (GTK_ENTRY (um->old_password_entry));
-                gtk_widget_show (um->old_password_checkmark);
+                set_entry_validation_checkmark (GTK_ENTRY (um->old_password_entry));
         }
 
         update_sensitivity (um);
@@ -387,9 +367,10 @@ old_password_entry_timeout (UmPasswordDialog *um)
 {
         const char *text;
 
+        update_sensitivity (um);
+
         text = gtk_entry_get_text (GTK_ENTRY (um->old_password_entry));
         if (strlen (text) > 0 && !um->old_password_ok) {
-                begin_action (um);
                 passwd_authenticate (um->passwd_handler, text, (PasswdCallback)auth_cb, um);
         }
 
@@ -423,26 +404,30 @@ old_password_entry_changed (GtkEntry         *entry,
                 um->old_password_entry_timeout_id = 0;
         }
 
-        gtk_widget_hide (um->old_password_checkmark);
         clear_entry_validation_error (GTK_ENTRY (entry));
-        um->old_password_ok = FALSE;
-        update_sensitivity (um);
+        gtk_widget_set_sensitive (um->ok_button, FALSE);
 
+        um->old_password_ok = FALSE;
         um->old_password_entry_timeout_id = g_timeout_add (PASSWORD_CHECK_TIMEOUT,
                                                            (GSourceFunc) old_password_entry_timeout,
                                                            um);
 }
 
 static void
-hint_allocate (GtkWidget        *label,
-               GtkAllocation    *allocation,
-               UmPasswordDialog *um)
+on_generate (GtkEntry             *entry,
+             GtkEntryIconPosition  pos,
+             GdkEventButton       *event,
+             UmPasswordDialog     *um)
 {
-        gint height;
+        gchar *pwd;
 
-        /* Allocate enought space for hint and don't change */
-        height = gtk_widget_get_allocated_height (um->strength_indicator_label);
-        gtk_widget_set_size_request (label, allocation->width, height * 3);
+        pwd = pw_generate ();
+
+        gtk_entry_set_text (GTK_ENTRY (um->password_entry), pwd);
+        gtk_entry_set_text (GTK_ENTRY (um->verify_entry), pwd);
+        gtk_entry_set_visibility (GTK_ENTRY (um->password_entry), TRUE);
+
+        g_free (pwd);
 }
 
 UmPasswordDialog *
@@ -452,7 +437,6 @@ um_password_dialog_new (void)
         GError *error;
         UmPasswordDialog *um;
         GtkWidget *widget;
-        gint len;
 
         builder = gtk_builder_new ();
 
@@ -493,39 +477,36 @@ um_password_dialog_new (void)
                           G_CALLBACK (password_entry_changed), um);
         g_signal_connect_after (widget, "focus-out-event",
                                 G_CALLBACK (password_entry_focus_out), um);
+        g_signal_connect_swapped (widget, "activate", G_CALLBACK (password_entry_timeout), um);
         gtk_entry_set_visibility (GTK_ENTRY (widget), FALSE);
         um->password_entry = widget;
+        g_signal_connect (widget, "icon-press", G_CALLBACK (on_generate), um);
 
         widget = (GtkWidget *) gtk_builder_get_object (builder, "old-password-entry");
         g_signal_connect_after (widget, "focus-out-event",
                                 G_CALLBACK (old_password_entry_focus_out), um);
         g_signal_connect (widget, "notify::text",
                           G_CALLBACK (old_password_entry_changed), um);
+        g_signal_connect_swapped (widget, "activate", G_CALLBACK (password_entry_timeout), um);
         um->old_password_entry = widget;
         um->old_password_label = (GtkWidget *) gtk_builder_get_object (builder, "old-password-label");
-        um->old_password_spinner = (GtkWidget *) gtk_builder_get_object (builder, "old-password-spinner");
-        um->old_password_checkmark = (GtkWidget *) gtk_builder_get_object (builder, "old-password-checkmark");
-        um->old_password_entry_timeout_id = 0;
 
         widget = (GtkWidget *) gtk_builder_get_object (builder, "verify-entry");
         g_signal_connect (widget, "notify::text",
                           G_CALLBACK (password_entry_changed), um);
         g_signal_connect_after (widget, "focus-out-event",
                                 G_CALLBACK (password_entry_focus_out), um);
+        g_signal_connect_swapped (widget, "activate", G_CALLBACK (password_entry_timeout), um);
         um->verify_entry = widget;
-        um->password_entry_timeout_id = 0;
-
-        widget = (GtkWidget *) gtk_builder_get_object (builder, "strength-indicator-label");
-        len = pw_strength_hint_get_width_chars ();
-        gtk_label_set_width_chars (GTK_LABEL (widget), len);
-        um->strength_indicator_label = widget;
 
         um->strength_indicator = (GtkWidget *) gtk_builder_get_object (builder, "strength-indicator");
 
         widget = (GtkWidget *)gtk_builder_get_object (builder, "password-hint");
-        g_signal_connect (widget, "size-allocate", G_CALLBACK (hint_allocate), um);
         um->password_hint = widget;
 
+        widget = (GtkWidget *)gtk_builder_get_object (builder, "verify-hint");
+        um->verify_hint = widget;
+
         g_object_unref (builder);
 
         return um;
@@ -568,8 +549,9 @@ um_password_dialog_set_user (UmPasswordDialog *um,
                 gtk_entry_set_text (GTK_ENTRY (um->password_entry), "");
                 gtk_entry_set_text (GTK_ENTRY (um->verify_entry), "");
                 gtk_entry_set_text (GTK_ENTRY (um->old_password_entry), "");
-                gtk_widget_hide (um->old_password_checkmark);
-                gtk_widget_hide (um->old_password_spinner);
+
+                gtk_entry_set_visibility (GTK_ENTRY (um->password_entry), FALSE);
+                gtk_entry_set_visibility (GTK_ENTRY (um->verify_entry), FALSE);
 
                 if (act_user_get_uid (um->user) == getuid ()) {
                         mode_change (um, ACT_USER_PASSWORD_MODE_REGULAR);
