@@ -621,9 +621,13 @@ get_login_time_text (ActUser *user)
         else if (time > 0) {
                 date_time = g_date_time_new_from_unix_local (time);
                 date_str = get_smart_date (date_time);
-                time_str = g_date_time_format (date_time, "%k:%M");
+                /* Translators: This is a time format string in the style of "22:58".
+                   It indicates a login time which follows a date. */
+                time_str = g_date_time_format (date_time, C_("login date-time", "%k:%M"));
 
-                text = g_strconcat (date_str, ", ", time_str, NULL);
+                /* Translators: This indicates a login date-time.
+                   The first %s is a date, and the second %s a time. */
+                text = g_strdup_printf(C_("login date-time", "%s, %s"), date_str, time_str);
 
                 g_date_time_unref (date_time);
                 g_free (date_str);
@@ -648,6 +652,8 @@ get_autologin_possible (ActUser *user)
         return !(locked || set_password_at_login);
 }
 
+static void on_permission_changed (GPermission *permission, GParamSpec *pspec, gpointer data);
+
 static void
 show_user (ActUser *user, CcUserPanelPrivate *d)
 {
@@ -738,9 +744,10 @@ show_user (ActUser *user, CcUserPanelPrivate *d)
         widget = get_widget (d, "last-login-history-button");
         gtk_widget_set_visible (widget, show);
         gtk_widget_set_sensitive (widget, enable);
-}
 
-static void on_permission_changed (GPermission *permission, GParamSpec *pspec, gpointer data);
+        if (d->permission != NULL)
+                on_permission_changed (d->permission, NULL, d);
+}
 
 static void
 selected_user_changed (GtkTreeSelection *selection, CcUserPanelPrivate *d)
@@ -752,8 +759,6 @@ selected_user_changed (GtkTreeSelection *selection, CcUserPanelPrivate *d)
         if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
                 gtk_tree_model_get (model, &iter, USER_COL, &user, -1);
                 show_user (user, d);
-                if (d->permission != NULL)
-                        on_permission_changed (d->permission, NULL, d);
                 gtk_widget_set_sensitive (get_widget (d, "main-user-vbox"), TRUE);
                 g_object_unref (user);
         } else {
